@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -104,6 +100,8 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "cch", "atsam" },
             { "mwr", "marwari" },
             { "Zsye", "emoji" },
+            { "%%NJIVA", "dialect Gniva/Njiva" },
+            { "ccp", "chakma" },
             { "egy", "egiptean\u0103 veche" },
             { "raj", "rajasthani" },
             { "tem", "timne" },
@@ -120,7 +118,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "AG", "Antigua \u0219i Barbuda" },
             { "type.ca.ethiopic", "calendar etiopian" },
             { "AI", "Anguilla" },
-            { "key.tz", "Fusul orar" },
+            { "key.tz", "fus orar" },
             { "AL", "Albania" },
             { "AM", "Armenia" },
             { "AO", "Angola" },
@@ -133,6 +131,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "AX", "Insulele \u00c5land" },
             { "mye", "myene" },
             { "AZ", "Azerbaidjan" },
+            { "%%AREVELA", "armean\u0103 oriental\u0103" },
             { "BA", "Bosnia \u0219i Her\u021begovina" },
             { "BB", "Barbados" },
             { "ceb", "cebuan\u0103" },
@@ -200,6 +199,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "DO", "Republica Dominican\u0103" },
             { "gor", "gorontalo" },
             { "got", metaValue_got },
+            { "Mtei", "meitei mayek" },
             { "zun", "zuni" },
             { "tig", "tigre" },
             { "DZ", "Algeria" },
@@ -239,13 +239,12 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "FJ", "Fiji" },
             { "FK", "Insulele Falkland" },
             { "FM", "Micronezia" },
-            { "key.va", "Varianta local\u0103" },
+            { "key.va", "variant\u0103 local\u0103" },
             { "FO", "Insulele Feroe" },
             { "Taml", metaValue_ta },
             { "FR", "Fran\u021ba" },
             { "tkl", "tokelau" },
             { "grb", "grebo" },
-            { "root", "root" },
             { "type.ca.indian", "calendar na\u021bional indian" },
             { "grc", "greac\u0103 veche" },
             { "GA", "Gabon" },
@@ -275,7 +274,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "GY", "Guyana" },
             { "ckb", "kurd\u0103 central\u0103" },
             { "zxx", "far\u0103 con\u021binut lingvistic" },
-            { "HK", "R.A.S. Hong Kong a Chinei" },
+            { "HK", "R.A.S. Hong Kong, China" },
             { "HM", "Insula Heard \u0219i Insulele McDonald" },
             { "HN", "Honduras" },
             { "HR", "Croa\u021bia" },
@@ -304,6 +303,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "IT", "Italia" },
             { "Zmth", "nota\u021bie matematic\u0103" },
             { "type.nu.thai", "cifre thailandeze" },
+            { "%%POSIX", "informatic\u0103" },
             { "type.nu.beng", "cifre bengaleze" },
             { "JE", "Jersey" },
             { "type.ca.islamic", "calendar islamic" },
@@ -311,6 +311,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "JM", "Jamaica" },
             { "JO", "Iordania" },
             { "JP", "Japonia" },
+            { "%%1606NICT", "francez\u0103 medieval\u0103 t\u00e2rzie p\u00e2n\u0103 la 1606" },
             { "ain", "ainu" },
             { "guz", "gusii" },
             { "tog", "nyasa tonga" },
@@ -368,12 +369,12 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "MH", "Insulele Marshall" },
             { "ale", "aleut\u0103" },
             { "type.nu.vaii", "Cifre Vai" },
-            { "MK", "Republica Macedonia" },
+            { "MK", "Macedonia de Nord" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Birmania)" },
             { "MN", "Mongolia" },
             { "new", "newari" },
-            { "MO", "R.A.S. Macao a Chinei" },
+            { "MO", "R.A.S. Macao, China" },
             { "MP", "Insulele Mariane de Nord" },
             { "MQ", "Martinica" },
             { "MR", "Mauritania" },
@@ -394,6 +395,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "type.co.dictionary", "Ordine de sortare a dic\u021bionarului" },
             { "NC", "Noua Caledonie" },
             { "%%WADEGILE", "Wade-Giles" },
+            { "%%UCRCOR", "ortografie revizuit\u0103 unificat\u0103 cornish" },
             { "NE", "Niger" },
             { "NF", "Insula Norfolk" },
             { "NG", "Nigeria" },
@@ -442,6 +444,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "niu", "niuean\u0103" },
             { "QO", "Oceania Periferic\u0103" },
             { "lez", "lezghian" },
+            { "%%FONUPA", "alfabet fonetic uralic" },
             { "tvl", "tuvalu" },
             { "001", "Lume" },
             { "002", "Africa" },
@@ -484,13 +487,13 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "type.nu.taml", "numerale tradi\u021bionale tamile" },
             { "SR", "Suriname" },
             { "SS", "Sudanul de Sud" },
-            { "ST", "Sao Tome \u0219i Principe" },
+            { "ST", "S\u00e3o Tom\u00e9 \u0219i Pr\u00edncipe" },
             { "SV", "El Salvador" },
             { "ars", "arab\u0103 najdi" },
             { "SX", "Sint-Maarten" },
             { "SY", "Siria" },
             { "yao", "yao" },
-            { "SZ", "Swaziland" },
+            { "SZ", "Eswatini" },
             { "arw", "arawak" },
             { "yap", "yapez\u0103" },
             { "TA", "Tristan da Cunha" },
@@ -500,16 +503,18 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "TC", "Insulele Turks \u0219i Caicos" },
             { "yav", "yangben" },
             { "TD", "Ciad" },
+            { "Qaag", "zawgyi" },
             { "TF", "Teritoriile Australe \u0219i Antarctice Franceze" },
             { "TG", "Togo" },
             { "TH", "Thailanda" },
             { "TJ", "Tadjikistan" },
             { "029", "Caraibe" },
             { "TK", "Tokelau" },
-            { "TL", "Timorul de Est" },
+            { "TL", "Timor-Leste" },
             { "ybb", "yemba" },
             { "type.co.searchjl", "C\u0103uta\u021bi \u00een func\u021bie de consoana ini\u021bial\u0103 hangul" },
             { "TM", "Turkmenistan" },
+            { "%%BOONT", "boontling" },
             { "TN", "Tunisia" },
             { "TO", "Tonga" },
             { "TR", "Turcia" },
@@ -537,11 +542,12 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "UN", "Na\u021biunile Unite" },
             { "US", "Statele Unite ale Americii" },
             { "haw", "hawaiian\u0103" },
+            { "%%1959ACAD", "belarus\u0103 academic\u0103" },
             { "type.co.gb2312han", "sortare pentru chineza simplificat\u0103 - GB2312" },
             { "UY", "Uruguay" },
             { "prg", "prusac\u0103" },
             { "UZ", "Uzbekistan" },
-            { "tzm", "tamazight central marocan\u0103" },
+            { "tzm", "tamazight din Atlasul Central" },
             { "type.co.stroke", "ordine de sortare dup\u0103 trasare" },
             { "nnh", "ngiemboon" },
             { "VA", "Statul Cet\u0103\u021bii Vaticanului" },
@@ -556,6 +562,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "rwk", "rwa" },
             { "non", "nordic\u0103 veche" },
             { "053", "Australasia" },
+            { "%%AREVMDA", "armean\u0103 occidental\u0103" },
             { "054", "Melanezia" },
             { "WF", "Wallis \u0219i Futuna" },
             { "type.co.traditional", "sortare tradi\u021bional\u0103" },
@@ -568,17 +575,21 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "WS", "Samoa" },
             { "wal", "wolaita" },
             { "was", "washo" },
+            { "XA", "Pseudo-accente" },
             { "war", "waray" },
+            { "XB", "Pseudo-Bidi" },
             { "awa", "awadhi" },
             { "061", "Polinezia" },
             { "XK", "Kosovo" },
             { "Gujr", metaValue_gu },
             { "Zxxx", "nescris\u0103" },
+            { "Olck", "ol chiki" },
             { "wbp", "warlpiri" },
             { "YE", "Yemen" },
             { "nqo", "n\u2019ko" },
             { "type.co.standard", "ordine de sortare standard" },
             { "fan", "fang" },
+            { "%%ROZAJ", "dialect resian" },
             { "fat", "fanti" },
             { "YT", "Mayotte" },
             { "ZA", "Africa de Sud" },
@@ -596,7 +607,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "lol", "mongo" },
             { "nso", "sotho de nord" },
             { "type.nu.telu", "cifre telugu" },
-            { "lou", "creol\u0103 louisianez\u0103" },
+            { "lou", "creol\u0103 (Louisiana)" },
             { "loz", "lozi" },
             { "jmc", "machame" },
             { "type.nu.hansfin", "numerale financiare chineze\u0219ti simplificate" },
@@ -618,6 +629,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "type.nu.roman", "numerale romane" },
             { "sah", "sakha" },
             { "sam", "aramaic\u0103 samaritean\u0103" },
+            { "%%SCOUSE", "dialect scouse" },
             { "saq", "samburu" },
             { "sas", "sasak" },
             { "sat", "santali" },
@@ -648,11 +660,13 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "bas", "basaa" },
             { "bax", "bamun" },
             { "jrb", "iudeo-arab\u0103" },
+            { "es_ES", "spaniol\u0103 (Europa)" },
             { "nzi", "nzima" },
             { "sco", "scots" },
             { "scn", "sicilian\u0103" },
             { "aa", "afar" },
             { "ab", "abhaz\u0103" },
+            { "Aran", "nastaaliq" },
             { "ae", "avestan\u0103" },
             { "af", "afrikaans" },
             { "ak", "akan" },
@@ -660,6 +674,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "am", "amharic\u0103" },
             { "Arab", metaValue_ar },
             { "an", "aragonez\u0103" },
+            { "%%SOLBA", "dialect Stolvizza/Solbica" },
             { "Jpan", metaValue_ja },
             { "ar", metaValue_ar },
             { "Hrkt", "silabic\u0103 japonez\u0103" },
@@ -670,9 +685,10 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "sdh", "kurd\u0103 de sud" },
             { "ay", "aymara" },
             { "az", "azer\u0103" },
+            { "%%OSOJS", "dialect Oseacco/Osojane" },
             { "ba", "ba\u0219kir\u0103" },
             { "type.co.unihan", "Ordine de sortare a liniilor ideogramelor" },
-            { "be", "bielorus\u0103" },
+            { "be", "belarus\u0103" },
             { "bg", "bulgar\u0103" },
             { "bi", "bislama" },
             { "bm", "bambara" },
@@ -690,6 +706,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "ses", "koyraboro Senni" },
             { "ce", "cecen\u0103" },
             { "ch", "chamorro" },
+            { "%%REVISED", "ortografie revizuit\u0103" },
             { "co", "corsican\u0103" },
             { "Orya", "oriya" },
             { "cr", "cree" },
@@ -699,6 +716,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "cy", "galez\u0103" },
             { "type.nu.ethi", "numerale etiopiene" },
             { "da", "danez\u0103" },
+            { "pt_PT", "portughez\u0103 (Europa)" },
             { "de", "german\u0103" },
             { "type.cf.standard", "Format moned\u0103 standard" },
             { "bej", "beja" },
@@ -740,7 +758,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "fon", "fon" },
             { "bgn", "baluchi occidental\u0103" },
             { "yue", "cantonez\u0103" },
-            { "fo", "faroez\u0103" },
+            { "fo", "feroez\u0103" },
             { "type.m0.bgn", "transliterare BGN SUA" },
             { "umb", "umbundu" },
             { "fr", "francez\u0103" },
@@ -768,13 +786,14 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "hy", metaValue_hy },
             { "hz", "herero" },
             { "frc", "francez\u0103 cajun" },
+            { "%%FONIPA", "alfabet fonetic interna\u021bional" },
             { "ia", "interlingua" },
             { "Jamo", "jamo" },
             { "id", "indonezian\u0103" },
             { "type.nu.tibt", "cifre tibetane" },
             { "ie", "interlingue" },
             { "ig", "igbo" },
-            { "ii", "sichuan yi" },
+            { "ii", "yi din Sichuan" },
             { "frm", "francez\u0103 medie" },
             { "ik", "inupiak" },
             { "fro", "francez\u0103 veche" },
@@ -791,16 +810,16 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "sma", "sami de sud" },
             { "jv", metaValue_jv },
             { "mad", "madurez\u0103" },
-            { "smj", "lule sami" },
+            { "smj", "sami lule" },
             { "mag", "magahi" },
             { "maf", "mafa" },
             { "mai", "maithili" },
-            { "smn", "inari sami" },
+            { "smn", "sami inari" },
             { "ka", metaValue_ka },
             { "bla", "siksika" },
             { "mak", "makasar" },
             { "wuu", "chinez\u0103 wu" },
-            { "sms", "skolt sami" },
+            { "sms", "sami skolt" },
             { "man", "mandingo" },
             { "kg", "congolez\u0103" },
             { "Goth", metaValue_got },
@@ -864,6 +883,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "ny", "nyanja" },
             { "kac", "kachin" },
             { "kab", "kabyle" },
+            { "%%POLYTON", "politonic\u0103" },
             { "oc", "occitan\u0103" },
             { "kaj", "jju" },
             { "kam", "kamba" },
@@ -881,6 +901,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "pa", "punjabi" },
             { "dua", "duala" },
             { "srr", "serer" },
+            { "%%LIPAW", "dialect lipovaz din resian\u0103" },
             { "kbl", "kanembu" },
             { "pi", "pali" },
             { "pl", "polonez\u0103" },
@@ -894,7 +915,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "mgh", "makhuwa-meetto" },
             { "key.cf", "Format moned\u0103" },
             { "bra", "braj" },
-            { "key.ca", "calendar" },
+            { "key.ca", "tip calendar" },
             { "Laoo", metaValue_lo },
             { "mgo", "meta\u2019" },
             { "type.hc.h23", "sistem cu 24 de ore (0\u201323)" },
@@ -912,6 +933,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "rn", "kirundi" },
             { "key.cu", "moned\u0103" },
             { "ro", "rom\u00e2n\u0103" },
+            { "%%SAAHO", "dialect saho" },
             { "type.nu.orya", "cifre oriya" },
             { "type.nu.hanidec", "numerale zecimale chineze\u0219ti" },
             { "ru", "rus\u0103" },
@@ -922,6 +944,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "mic", "micmac" },
             { "suk", "sukuma" },
             { "sa", "sanscrit\u0103" },
+            { "%%UCCOR", "ortografie unificat\u0103 cornish" },
             { "sc", "sardinian\u0103" },
             { "sus", "susu" },
             { "sd", "sindhi" },
@@ -944,6 +967,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "Java", metaValue_jv },
             { "st", "sesotho" },
             { "su", "sundanez\u0103" },
+            { "%%NEDIS", "dialect Natisone" },
             { "sv", "suedez\u0103" },
             { "sw", "swahili" },
             { "type.nu.hantfin", "numerale financiare chineze\u0219ti tradi\u021bionale" },
@@ -974,6 +998,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "dyu", "dyula" },
             { "tw", "twi" },
             { "ty", "tahitian\u0103" },
+            { "%%BISKE", "dialect San Giorgio/Bila" },
             { "150", "Europa" },
             { "151", "Europa Oriental\u0103" },
             { "154", "Europa Septentrional\u0103" },
@@ -986,10 +1011,12 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "uk", "ucrainean\u0103" },
             { "type.ca.coptic", "calendar copt" },
             { "ur", "urdu" },
+            { "%%1994", "ortografie resian\u0103 standardizat\u0103" },
             { "xal", "calmuc\u0103" },
             { "zen", "zenaga" },
             { "uz", "uzbec\u0103" },
             { "kha", "khasi" },
+            { "%%1996", "ortografie german\u0103 de la 1996" },
             { "nds_NL", "saxona de jos" },
             { "ve", "venda" },
             { "type.ca.roc", "calendarul Republicii Chineze" },
@@ -997,6 +1024,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "kho", "khotanez\u0103" },
             { "khq", "koyra chiini" },
             { "key.hc", "ciclu orar (12 sau 24)" },
+            { "%%TARASK", "ortografie taraskievica" },
             { "vo", "volapuk" },
             { "syc", "siriac\u0103 clasic\u0103" },
             { "quc", "quich\u00e9" },
@@ -1029,6 +1057,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "byv", "medumba" },
             { "moh", "mohawk" },
             { "kkj", "kako" },
+            { "%%1694ACAD", "francez\u0103 modern\u0103 veche" },
             { "Syrc", metaValue_syr },
             { "yi", "idi\u0219" },
             { "mos", "mossi" },
@@ -1045,6 +1074,7 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "key.lb", "stil de \u00eentrerupere a liniei" },
             { "zu", "zulu" },
             { "type.co.phonebook", "sortare dup\u0103 cartea de telefon" },
+            { "%%MONOTON", "monotonic\u0103" },
             { "Geor", metaValue_ka },
             { "kmb", "kimbundu" },
             { "type.nu.jpanfin", "numerale financiare japoneze" },
@@ -1056,15 +1086,19 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "ebu", "embu" },
             { "Egyp", "hieroglife egiptene" },
             { "Geok", "georgian\u0103 bisericeasc\u0103" },
+            { "zh_Hans", "chinez\u0103 simplificat\u0103" },
             { "koi", "komi-permiak" },
             { "Hung", "maghiar\u0103 veche" },
             { "kok", "konkani" },
+            { "%%1901", "ortografie german\u0103 tradi\u021bional\u0103" },
             { "kos", "kosrae" },
             { "zh_Hant", "chinez\u0103 tradi\u021bional\u0103" },
             { "kpe", "kpelle" },
             { "type.nu.khmr", "cifre khmere" },
             { "ilo", "iloko" },
+            { "%%VALENCIA", "valencian\u0103" },
             { "Cprt", "cipriot\u0103" },
+            { "%%BAKU1926", "alfabet latin altaic unificat" },
             { "mua", "mundang" },
             { "type.nu.guru", "cifre gurmukhi" },
             { "mul", "mai multe limbi" },
@@ -1073,11 +1107,13 @@ public class LocaleNames_ro extends OpenListResourceBundle {
             { "mus", "creek" },
             { "Glag", "glagolitic\u0103" },
             { "gil", "gilbertin\u0103" },
+            { "%%KKCOR", "ortografie comuna cornish" },
             { "car", "carib" },
             { "cay", "cayuga" },
             { "type.nu.tamldec", "cifre tamile" },
             { "krc", "karaceai-balkar" },
             { "inh", "ingu\u0219\u0103" },
+            { "fa_AF", "dari" },
             { "krl", "karelian\u0103" },
             { "efi", "efik" },
             { "key.nu", "numere" },
