@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -77,8 +73,6 @@ public class LocaleNames_sw_CD extends OpenListResourceBundle {
             { "BJ", "Benini" },
             { "CI", "Kodivaa" },
             { "CX", "Kisiwa cha Christmas" },
-            { "CY", "Saiprasi" },
-            { "DK", "Denmaki" },
             { "HR", "Kroeshia" },
             { "JO", "Yordani" },
             { "LB", "Lebanoni" },
@@ -87,7 +81,6 @@ public class LocaleNames_sw_CD extends OpenListResourceBundle {
             { "LV", "Lativia" },
             { "MA", "Moroko" },
             { "MM", "Myama" },
-            { "MV", "Maldivi" },
             { "NE", "Nijeri" },
             { "NG", "Nijeria" },
             { "NO", "Norwe" },
@@ -99,7 +92,6 @@ public class LocaleNames_sw_CD extends OpenListResourceBundle {
             { "ST", "Sao Tome na Prinsipe" },
             { "TD", "Chadi" },
             { "TL", "Timori ya Mashariki" },
-            { "VN", "Vietnamu" },
             { "ak", "Kiakan" },
             { "az", "Kiazabajani" },
             { "gv", "Kimanksi" },
@@ -112,13 +104,11 @@ public class LocaleNames_sw_CD extends OpenListResourceBundle {
             { "hup", "Kihupa" },
             { "jbo", "Kilojban" },
             { "kac", "Kikachin" },
-            { "khq", "Kikoyra Chiini" },
             { "kkj", "Kikako" },
             { "koi", "Kikomipermyak" },
             { "kru", "Kikurukh" },
             { "kum", "Kikumyk" },
             { "lam", "Kilamba" },
-            { "mak", "mak" },
             { "mdf", "Kimoksha" },
             { "mic", "Kimikmaki" },
             { "moh", "Kimohoki" },
