@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -71,7 +67,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
-               "Grinwi\u00e7 bo\u00fdun\u00e7a orta wagt",
+               "Grinwi\u00e7 orta\u00e7a wagty",
                "",
                "",
                "",
@@ -734,14 +730,6 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
                "Lord-Hau wagty",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Makkuori adasy wagty",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Markiz adalary wagty",
                "",
@@ -1268,7 +1256,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Aqtobe", Kazakhstan_Western },
@@ -1368,7 +1356,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
                 new String[] {
-                    "Grinwi\u00e7 bo\u00fdun\u00e7a orta wagt",
+                    "Grinwi\u00e7 orta\u00e7a wagty",
                     "",
                     "Irlandi\u00fda standart wagty",
                     "",
@@ -1380,7 +1368,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
-                    "Grinwi\u00e7 bo\u00fdun\u00e7a orta wagt",
+                    "Grinwi\u00e7 orta\u00e7a wagty",
                     "",
                     "Be\u00fdik Britani\u00fda tomusky wagty",
                     "",
@@ -1416,7 +1404,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1440,7 +1428,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
-                    "Grinwi\u00e7 bo\u00fdun\u00e7a orta wagt",
+                    "Grinwi\u00e7 orta\u00e7a wagty",
                     "",
                     "Be\u00fdik Britani\u00fda tomusky wagty",
                     "",
@@ -1540,7 +1528,6 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1620,7 +1607,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1660,7 +1647,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1954,6 +1941,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "timezone.excity.America/St_Johns", "Sent-Jons" },
             { "timezone.excity.America/St_Kitts", "Sent-Kits" },
             { "timezone.excity.America/St_Lucia", "Sent-L\u00fdusi\u00fda" },
+            { "timezone.excity.America/Winnipeg", "Winnipeg" },
             { "timezone.excity.Antarctica/Casey", "Ke\u00fdsi" },
             { "timezone.excity.Antarctica/Davis", "De\u00fdwis" },
             { "timezone.excity.Antarctica/Syowa", "S\u00fdowa" },
